<?php
/* 
 *******************************************
 plugin JUpload for Coppermine Photo Gallery
 *******************************************

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
 ********************************************
 $Revision: 185 $
 $Author: etienne_sf $
 $Date: 2008-03-12 20:26:16 +0100 (mer., 12 mars 2008) $
 ********************************************
 *
 * Allows easy upload to the gallery, through a java applet. 
 * 
 * Up to date version of this script can be retrieved with the full JUpload package, here:
 * 
 * http://etienne.sf.free.fr/wiki
 * 
 * Directly here:
 * http://forum.coppermine-gallery.net/index.php/board,100.0.html
 * 
 * Support is available on this forum:
 * http://coppermine-gallery.net/forum/index.php?topic=43432
 * 
 * The applet is published on sourceforge:
 * http://jupload.sourceforge.net
 * 
 */

/*
 * This include is meant to add additional functions, for script that need to manage pictures.
 * 
 * It is based on the folowing facts:
 * 1) A lot of scripts have specific internal functions to manage the incoming file. 
 *   At least these scripts: db_input, upload, jupload, addpic, xp_publish.
 * 2) Each are slightly different, which means: it's not possible to directly reuse them in another script
 * 3) As these scripts also do input (mix between code that produce output and code that should be included), it's
 *   not possible to include them in another one to reuse code.
 * 4) If a bug exists (especially if it involve security), it's possible that several correction have to be done.
 * 5) Changing anything in the picture management system may become difficult, because many functions can have to be
 * modified.
 * 
 * 
 * 
 * 
 * This picmgmt.inc.php lacks these functions, that should be centralized and reused in all other scripts:
 * a) handle_one_uploaded_file()
 *   There are at least three scripts that manage uploaded pictures. By upload, I mean sent by an HTTP upload request.
 * b) add_physical_file()
 *   Should be called by handle_one_uploaded_file(), or, for instance, by a script that would unzip an incoming zip file. This 
 *   script should manage strange characters, and make any checks that lacks in add_picture, then call add_picture.
 * c) after_upload()
 *   This function should be called after each successful upload. Currently, it only send a mail if the gallery
 *   is configured to do it.
 * 
 *   The aim of this script is to provide these additional functions. Perhaps it will be incorporated into the
 * picmgmt.inc.php file ...
 *  
 */


if (!defined('IN_COPPERMINE')) { die('Not in Coppermine...');}
if (!defined('JUPLOAD_PHP')) { die('Not in Jupload...');}



// Add 'edit' directory if it doesn't exist
// Set access to read+write only
if (!is_dir($CONFIG['fullpath'].'edit')) {
    $cpg_umask = umask(0);
    @mkdir($CONFIG['fullpath'].'edit',0777);
    umask($cpg_umask);
    unset($cpg_umask);
}

logDebug("In j_picmgmt.inc.php (100) (bis)");


/**
 * jupload_cpg_die supersedes the cpg_die functions, for the next functions in this package. It allows
 * to just return a value, or create an HTML error page, depending on the value of the $callCpgDie global var.
 * 
 */
function jupload_cpg_die($msg_code, $msg_text,  $error_file, $error_line, $output_buffer = false) {
	global $callCpgDie, $ERROR;

	//If we forgot to initialize $callCpgDie, or if it's true, we do it the standard way.	
	if (!isset($callCpgDie)) {
		$callCpgDie = true;
	}
	
	$ERROR = "($msg_code) $msg_text\n";
	//Removes line feeds
	$ERROR = str_replace('<br />', ' ', $ERROR);
	//Encode properly, so that 'strange' characters display normally, once in the applet.
	$ERROR = 'ERROR: ' . strip_tags($ERROR);
	if (function_exists('mb_convert_encoding')) {
			$ERROR = mb_convert_encoding($ERROR, "UTF-8");
	}				
	
	if ($callCpgDie) {
		return cpg_die($msg_code, $msg_text,  $error_file, $error_line, $output_buffer);
	} else {
		//In an upload controled by the applet, we just want the error text in the output. The applet will then 
		//interpret this string, which sould be 'SUCCESS' or 'ERROR: msg'.
		die($ERROR);
	}
}


/*
 * Let's include the relevant j_upload_management file.

 */
if (isset($supercage)) {
	//We're in Coppermine 1.5
	include("plugins/jupload/include/j_upload_management.cpg1.5.inc.php");
} else {
	//We're in Coppermine 1.4
	include("plugins/jupload/include/j_upload_management.cpg1.4.inc.php");
}

